<?php 
/**
 * @package Wapple_Architect
 * @author Rich Gubby
 * @version 1.3.2
 */
/*
Plugin Name: Wapple Architect
Plugin URI: http://mobilewebjunkie.com/wordpress-mobile-plugin-install-guide-and-faq/
Description: Wapple Architect Mobile Plugin for Wordpress is a plugin that allows you to mobilize your blog in minutes. After activating this plugin visit <a href="options-general.php?page=architect.php">the settings page</a> and enter your Wapple Architect Dev Key.
Author: Rich Gubby
Version: 1.3.2
Author URI: http://mobilewebjunkie.com/
*/

/** 
 * Define some defaults - shouldn't need to change these
 * Defaults are now inserted into the DB at installation - these are left in for legacy versions
 */
// Width of images on the homepage
define('ARCHITECT_HOME_IMAGESCALE', 50);
// Quality of images on the homepage
define('ARCHITECT_HOME_IMAGEQUALITY', 95);
// Width of images on post pages
define('ARCHITECT_SINGLE_IMAGESCALE', 50);
// Quality of images on post pages
define('ARCHITECT_SINGLE_IMAGEQUALITY', 95);
// Width of images on designated pages
define('ARCHITECT_PAGE_IMAGESCALE', 50);
// Quality of images on designated pages
define('ARCHITECT_PAGE_IMAGEQUALITY', 95);
// Length of chars in post before a new page
define('ARCHITECT_SINGLE_PAGINGLENGTH', 2000);

/**
 * Debug purposes only - you shouldn't need to change these
 */ 
// Define whether a SOAP call is to be made - won't work without it!
define('ARCHITECT_DO_SOAP', true);
// Force the mobile check to always return true
define('ARCHITECT_FORCE_MOBILE', false);
// Turn a bit more debug on than is normal
define('ARCHITECT_DEBUG', false);

if(ARCHITECT_DEBUG)
{
	error_reporting(E_ALL);
	ini_set('display_errors', true);
}

if ( !defined('WP_CONTENT_DIR') )
	define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' ); // no trailing slash, full paths only - WP_CONTENT_URL is defined further down

if ( !defined('WP_PLUGIN_DIR') )
	define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' ); // full path, no trailing slash

if ( !defined('WP_CONTENT_URL') )
	define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content'); // full url - WP_CONTENT_DIR is defined further up
	
if ( !defined('WP_PLUGIN_URL') )
	define( 'WP_PLUGIN_URL', WP_CONTENT_URL . '/plugins' ); // full url, no trailing slash
	
if ( !defined('WP_UPLOAD_DIR') )
	define('WP_UPLOAD_DIR', WP_CONTENT_DIR . '/uploads' );

	
	
if(!class_exists('SoapClient') || !function_exists('simplexml_load_string') || (get_option('architect_devkey') == '' OR !get_option('architect_devkey')))
{
	function ArchitectInitError()
	{
		if(!isset($_REQUEST['page']) OR (isset($_REQUEST['page']) AND $_REQUEST['page'] != 'architect.php'))
		{
			echo '<div class="updated" style="background:#F24318;color:#000;border-color:#B23112;"><p>There was a problem initializing the Wapple Architect mobile plugin, please check <a href="options-general.php?page=architect.php">the Wapple Architect settings page</a> for more information</p></div>';
		}
	}
}

/**
 * Main device detection kick off function
 * - Sets up a few global variables that we're going to use later and initiates a check for mobile.
 * - If the check for mobile comes back true, amend the path to the theme
 * @return void
 */
function deviceDetection()
{
	// Only do this if we're on a non-admin page (for now!)
	if(!is_admin())
	{
		// Setup a global SOAP client so we can use the same one in the theme
		global $waplSoapClient;
		// Setup global headers so we don't have to get them twice
		global $waplHeaders;
		
		// Check if we've got SOAP and simpleXML installed - gracefully turns off mobile stuff if you haven't got it
		if(!class_exists('SoapClient'))
		{
			return false;
		}
		if(!function_exists('simplexml_load_string'))
		{
			return false;
		}
		
		// Create the SOAP client
		$waplSoapClient = __getSoapClient();
		// Get device / browser header information 
		$waplHeaders = __getHeaders();
		
		// If __testForMobile() comes back true, amend template path
		if(__testForMobile())
		{
			// Load the correct file depending on the URL (copied from template-loader.php)
			$template = __templateLoader();
			
			$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.$template;
			
			if(file_exists($file))
			{
				include($file);
				exit(0);
			}
		}
	}
}

/**
 * Work out which theme file to use
 * @return string
 */
function __templateLoader()
{
	if ( is_404()) {
		return '404.php';
	} else if ( is_search()) {
		return 'search.php';
	} else if ( is_home()) {
		return 'index.php';
	} else if ( is_single()) {
		return 'single.php';
	} else if ( is_page()) {
		return 'page.php';
	} else if ( is_archive()) {
		return 'archive.php';
	} else if (file_exists(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'index.php' )) {
		return 'index.php';
	}
}

/**
 * Perform a device detection check
 * @return boolean
 */
function __testForMobile()
{
	global $waplSoapClient;
	global $waplHeaders;
	
	if(isset($_REQUEST['mobile']) && $_REQUEST['mobile'] == 0)
	{
		setcookie('isMobile', "", time()-3600);
		setcookie('isMobile', "0", time()+3600);
		return false;
	}
	// If we've defined ARCHITECT_DO_SOAP, just return the value of ARCHITECT_FORCE_MOBILE
	if(!ARCHITECT_DO_SOAP)
	{
		return ARCHITECT_FORCE_MOBILE;
	}
	
	if(!get_option('architect_devkey'))
	{
		return false;
	}
	
	// Check for existence of a cookie
	if(isset($_COOKIE['isMobile']))
	{
		return $_COOKIE['isMobile'];
	} else
	{
		// Test for mobile
		$params = array(
			'devKey' => get_option('architect_devkey'),
			'deviceHeaders' => $waplHeaders
		);

		if(!is_object($waplSoapClient))
		{
			// We don't have a SOAP client
			return false;
		}
		$result = $waplSoapClient->isMobileDevice($params);
		if(is_soap_fault($result))
		{
			// There is a SOAP error! probably a dev key error
			return false;
		}  else
		{
			if($result)
			{
				// Set a cookie to remember the outcome!
				setcookie('isMobile', true, time()+3600);
				return true;
			} else
			{
				setcookie('isMobile', false, time()+3600);
				return false;
			}
		}
	}
}

/**
 * Get a SOAP client
 * @return mixed
 */
function __getSoapClient()
{
	if(ARCHITECT_DO_SOAP)
	{
		return new SoapClient('http://webservices.wapple.net/wapl.wsdl', array('exceptions' => 0));
	} else
	{
		return false;
	}	
}

/**
 * Build device header array that SOAP can use
 * @return array
 */
function __getHeaders()
{
	$headers = array();
	foreach($_SERVER as $key => $val)
	{
		$headers[] = array('name' => $key, 'value' => $val);
	}
	return $headers;
}

// Add the deviceDetection function to the template_redirect filter
add_action('template_redirect', 'deviceDetection');
// Add architect options to admin menu
add_action('admin_menu', 'add_architect_options_page');
// Add notice to WordPress if we have an architect error
if(function_exists('ArchitectInitError'))
{
	add_action('admin_head','ArchitectInitError');
}

/**
 * Add architect admin options
 * @return void
 */
function add_architect_options_page()
{
	add_options_page('Wapple Architect Settings', 'Wapple Architect', 8, basename(__FILE__), 'architect_options_page');
}

/**
 * Display architect options and save when requested
 * @return void
 */
function architect_options_page()
{
	echo '<div class="wrap">';
	
	if (isset($_POST['info_update'])) 
	{
		$updateOption = false;
		// Save Dev Key
		if($_POST['architect_devkey'] != get_option('architect_devkey'))
		{
			update_option('architect_devkey', $_POST['architect_devkey']);
			$updateOption = true;
		}
		// Show the blog description
		if($_POST['architect_show_blogdesc'] != get_option('architect_show_blogdesc'))
		{
			update_option('architect_show_blogdesc', $_POST['architect_show_blogdesc']);
			$updateOption = true;
		}
		// Save use header image
		if($_POST['architect_use_headerimage'] != get_option('architect_use_headerimage'))
		{
			update_option('architect_use_headerimage', $_POST['architect_use_headerimage']);
			$updateOption = true;
		}
		// Save actual header image
		if(isset($_FILES['architect_headerimage']))
		{
			$pathToHeader = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'header'.DIRECTORY_SEPARATOR;
			architect_check_path($pathToHeader);
			if(move_uploaded_file($_FILES['architect_headerimage']['tmp_name'], $pathToHeader.$_FILES['architect_headerimage']['name']))
			{
				update_option('architect_headerimage', $_FILES['architect_headerimage']['name']);
				$updateOption = true;
			}
		}
		// Save header image BG transparency col
		if($_POST['architect_headerimage_transparency_colour'] != get_option('architect_headerimage_transparency_colour'))
		{
			update_option('architect_headerimage_transparency_colour', $_POST['architect_headerimage_transparency_colour']);
			$updateOption = true;
		}
		// Is the header image a link back to the homepage
		if($_POST['architect_headerimagelinktohome'] != get_option('architect_headerimagelinktohome'))
		{
			update_option('architect_headerimagelinktohome', $_POST['architect_headerimagelinktohome']);
			$updateOption = true;
		}
		// Save use footer image
		if($_POST['architect_use_footerimage'] != get_option('architect_use_footerimage'))
		{
			update_option('architect_use_footerimage', $_POST['architect_use_footerimage']);
			$updateOption = true;
		}
		// Save actual footer image
		if(isset($_FILES['architect_footerimage']))
		{
			$pathToFooter = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'footer'.DIRECTORY_SEPARATOR;
			architect_check_path($pathToFooter);
			if(move_uploaded_file($_FILES['architect_footerimage']['tmp_name'], $pathToFooter.$_FILES['architect_footerimage']['name']))
			{
				update_option('architect_footerimage', $_FILES['architect_footerimage']['name']);
				$updateOption = true;
			}
		}
		// Save footer image BG transparency col
		if($_POST['architect_footerimage_transparency_colour'] != get_option('architect_footerimage_transparency_colour'))
		{
			update_option('architect_footerimage_transparency_colour', $_POST['architect_footerimage_transparency_colour']);
			$updateOption = true;
		}
		// Show footer text
		if($_POST['architect_showfootertext'] != get_option('architect_showfootertext'))
		{
			update_option('architect_showfootertext', $_POST['architect_showfootertext']);
			$updateOption = true;
		}
		// What is the footer text
		if($_POST['architect_footertext'] != get_option('architect_footertext'))
		{
			update_option('architect_footertext', $_POST['architect_footertext']);
			$updateOption = true;
		}
		// Save show menu at top
		if($_POST['architect_showmenuattop'] != get_option('architect_showmenuattop'))
		{
			update_option('architect_showmenuattop', $_POST['architect_showmenuattop']);
			$updateOption = true;
		}
		// Save show menu at bottom
		if($_POST['architect_showmenuatbottom'] != get_option('architect_showmenuatbottom'))
		{
			update_option('architect_showmenuatbottom', $_POST['architect_showmenuatbottom']);
			$updateOption = true;
		}
		// Save switch to desktop
		if($_POST['architect_showswitchtodesktop'] != get_option('architect_showswitchtodesktop'))
		{
			update_option('architect_showswitchtodesktop', $_POST['architect_showswitchtodesktop']);
			$updateOption = true;
		}
		// Save show author
		if($_POST['architect_showauthor'] != get_option('architect_showauthor'))
		{
			update_option('architect_showauthor', $_POST['architect_showauthor']);
			$updateOption = true;
		}
		// Save try and do forms
		if($_POST['architect_doform'] != get_option('architect_doform'))
		{
			update_option('architect_doform', $_POST['architect_doform']);
			$updateOption = true;
		}
		// Save show excerpt on home page
		if($_POST['architect_home_showexcerpt'] != get_option('architect_home_showexcerpt'))
		{
			update_option('architect_home_showexcerpt', $_POST['architect_home_showexcerpt']);
			$updateOption = true;
		}
		// Save home page excerpt override
		if($_POST['architect_home_excerpt_override'] != get_option('architect_home_excerpt_override'))
		{
			update_option('architect_home_excerpt_override', $_POST['architect_home_excerpt_override']);
			$updateOption = true;
		}
		// Save home page show categories
		if($_POST['architect_home_showcategories'] != get_option('architect_home_showcategories'))
		{
			update_option('architect_home_showcategories', $_POST['architect_home_showcategories']);
			$updateOption = true;
		}
		// Save home page image scale
		if($_POST['architect_home_imagescale'] != get_option('architect_home_imagescale'))
		{
			update_option('architect_home_imagescale', $_POST['architect_home_imagescale']);
			$updateOption = true;
		}
		// Save home page image quality
		if($_POST['architect_home_imagequality'] != get_option('architect_home_imagequality'))
		{
			update_option('architect_home_imagequality', $_POST['architect_home_imagequality']);
			$updateOption = true;
		}
		// Save number of posts on home page
		if($_POST['architect_home_posts_per_page'] != get_option('architect_home_posts_per_page'))
		{
			update_option('architect_home_posts_per_page', $_POST['architect_home_posts_per_page']);
			$updateOption = true;
		}
		// Save show more link
		if($_POST['architect_home_showmore'] != get_option('architect_home_showmore'))
		{
			update_option('architect_home_showmore', $_POST['architect_home_showmore']);
			$updateOption = true;
		}
		// Save post do paging
		if($_POST['architect_single_dopaging'] != get_option('architect_single_dopaging'))
		{
			update_option('architect_single_dopaging', $_POST['architect_single_dopaging']);
			$updateOption = true;
		}
		// Save post paging length
		if($_POST['architect_single_paginglength'] != get_option('architect_single_paginglength'))
		{
			update_option('architect_single_paginglength', $_POST['architect_single_paginglength']);
			$updateOption = true;
		}
		// Save show home link
		if($_POST['architect_single_showhome'] != get_option('architect_single_showhome'))
		{
			update_option('architect_single_showhome', $_POST['architect_single_showhome']);
			$updateOption = true;
		}
		// Save show post next link
		if($_POST['architect_single_shownext'] != get_option('architect_single_shownext'))
		{
			update_option('architect_single_shownext', $_POST['architect_single_shownext']);
			$updateOption = true;
		}
		// Save post image scale
		if($_POST['architect_single_imagescale'] != get_option('architect_single_imagescale'))
		{
			update_option('architect_single_imagescale', $_POST['architect_single_imagescale']);
			$updateOption = true;
		}
		// Save post image quality
		if($_POST['architect_single_imagequality'] != get_option('architect_single_imagequality'))
		{
			update_option('architect_single_imagequality', $_POST['architect_single_imagequality']);
			$updateOption = true;
		}
		// Save post response format
		if($_POST['architect_single_responseformat'] != get_option('architect_single_responseformat'))
		{
			update_option('architect_single_responseformat', $_POST['architect_single_responseformat']);
			$updateOption = true;
		}
		// Save allow post comments
		if($_POST['architect_single_allowcomments'] != get_option('architect_single_allowcomments'))
		{
			update_option('architect_single_allowcomments', $_POST['architect_single_allowcomments']);
			$updateOption = true;
		}
		// Save read more on post
		if($_POST['architect_single_nextpage'] != get_option('architect_single_nextpage'))
		{
			update_option('architect_single_nextpage', $_POST['architect_single_nextpage']);
			$updateOption = true;
		}
		// Save read less on post
		if($_POST['architect_single_prevpage'] != get_option('architect_single_prevpage'))
		{
			update_option('architect_single_prevpage', $_POST['architect_single_prevpage']);
			$updateOption = true;
		}
		
		// Save page image scale
		if($_POST['architect_page_imagescale'] != get_option('architect_page_imagescale'))
		{
			update_option('architect_page_imagescale', $_POST['architect_page_imagescale']);
			$updateOption = true;
		}
		// Save page image quality
		if($_POST['architect_page_imagequality'] != get_option('architect_page_imagequality'))
		{
			update_option('architect_page_imagequality', $_POST['architect_page_imagequality']);
			$updateOption = true;
		}
		// Save home show search
		if($_POST['architect_home_showsearch'] != get_option('architect_home_showsearch'))
		{
			update_option('architect_home_showsearch', $_POST['architect_home_showsearch']);
			$updateOption = true;
		}
		// Save search page show tags
		if($_POST['architect_search_showtags'] != get_option('architect_search_showtags'))
		{
			update_option('architect_search_showtags', $_POST['architect_search_showtags']);
			$updateOption = true;
		}
		// Save search page show categories
		if($_POST['architect_search_showcategories'] != get_option('architect_search_showcategories'))
		{
			update_option('architect_search_showcategories', $_POST['architect_search_showcategories']);
			$updateOption = true;
		}
		
		// Save Mobile stylesheet
		$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'style.css';
		architect_check_path(WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR);
		$stylesheet = file_get_contents($file);
		
		if(stripslashes($_POST['architect_stylesheet']) != $stylesheet)
		{
			if(file_put_contents($file, stripslashes($_POST['architect_stylesheet'])))
			{
				$updateOption = true;
			}
		}
		
		// Save custom stylesheet
		$custom_file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'custom_style.css';
		$custom_stylesheet = file_get_contents($custom_file);
		
		if(stripslashes($_POST['architect_custom_stylesheet']) != $custom_stylesheet)
		{
			if(file_put_contents($custom_file, stripslashes($_POST['architect_custom_stylesheet'])))
			{
				$updateOption = true;
			}
		}
		
		if($updateOption)
		{
			echo "<div class='updated fade'><p><strong>Wapple Architect settings saved.</strong></p></div>";
		}
	}
	
	if(get_option('architect_devkey') == '' OR !get_option('architect_devkey'))
	{
		echo '<div class="updated" style="background:#F24318;color:#000;border-color:#B23112;"><p><strong>You haven\'t saved your free Wapple Architect Dev Key, get one from here: <a href="http://wapple.net/register/free-developer-program-for-coding-mobile-web.htm" style="color:#000;">http://wapple.net/register/free-developer-program-for-coding-mobile-web.htm</a></strong></p></div>';
	}
	if(!class_exists('SoapClient'))
	{
		echo '<div class="updated" style="background:#F24318;color:#000;border-color:#B23112;"><p>You do not have SOAP installed, this plugin needs SOAP in order to communicate with Wapple\'s web services</p></div>';
	}
	if(!function_exists('simplexml_load_string'))
	{
		echo '<div class="updated" style="background:#F24318;color:#000;border-color:#B23112;"><p>You do not have simpleXML installed, this plugin needs simpleXML in order to parse XML returned from Wapple\'s web services</p></div>';
	}
	
	
	echo '<form method="post" action="options-general.php?page=architect.php" enctype="multipart/form-data">';
	echo architect_admin_header('2', 'Wapple Architect Settings');
	
	echo '<p><em>Wapple Architect WordPress plugin is brought to you by Rich Gubby - <a href="http://mobilewebjunkie.com">http://mobilewebjunkie.com</a></em></p>';

	echo architect_table_start();
	echo architect_admin_header('3', 'Basic Settings');	
	
	// Dev Key
	echo architect_admin_option('input', array('label' => 'Wapple Architect Dev Key', 'name' => 'architect_devkey', 'value' => get_option('architect_devkey'), 'description' => 'Enter your newly acquired Dev Key from Wapple'));

	// Show the blog description
	echo architect_admin_option('select', array('label' => 'Show blog description', 'name' => 'architect_show_blogdesc', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_show_blogdesc'), 'description' => 'Show blog description at the top of your page'));
	
	// Use a mobile header image
	echo architect_admin_option('select', array('label' => 'Use mobile header image', 'name' => 'architect_use_headerimage', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_use_headerimage'), 'description' => 'Use an image on your site to replace header text'));
	
	// Upload a mobile header image	
	echo architect_admin_option('file', array('label' => 'Mobile site header image', 'name' => 'architect_headerimage', 'description' => 'Browse your local computer for a header image'));
	
	// Transparency colour for header image
	echo architect_admin_option('input', array('label' => 'Header BG transparency colour', 'size' => 6, 'name' => 'architect_headerimage_transparency_colour', 'value' => get_option('architect_headerimage_transparency_colour'), 'before' => '#', 'description' => 'What background colour do you want your header image to have?'));
	
	// Show mobile header image preview
	if(get_option('architect_headerimage') AND get_option('architect_use_headerimage'))
	{
		if(file_exists(WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'header'.DIRECTORY_SEPARATOR.get_option('architect_headerimage')))
		{
			$src = '/wp-content/uploads/'.get_wapl_plugin_base().'/images/header/'.get_option('architect_headerimage');
		} else if(file_exists(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'header'.DIRECTORY_SEPARATOR.get_option('architect_headerimage')))
		{
			$src = '/wp-content/plugins/'.get_wapl_plugin_base().'/theme/images/header/'.get_option('architect_headerimage');
		}
		echo architect_admin_option('image', array('label' => 'Mobile site header image preview', 'alt' => 'Mobile Header Image', 'src' => $src));
	}
	
	// Header image as link -> homepage
	echo architect_admin_option('select', array('label' => 'Header image link back to home', 'name' => 'architect_headerimagelinktohome', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_headerimagelinktohome'), 'description' => 'Set your header image as a link back to the home page'));
	
	// Use a mobile footer image
	echo architect_admin_option('select', array('label' => 'Use mobile footer image', 'name' => 'architect_use_footerimage', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_use_footerimage'), 'description' => 'Use an image on your site to replace footer text'));
	
	// Upload a mobile footer image	
	echo architect_admin_option('file', array('label' => 'Mobile site footer image', 'name' => 'architect_footerimage', 'description' => 'Browse your local computer for a header image'));
	
	// Transparency colour for footer image
	echo architect_admin_option('input', array('label' => 'Footer BG transparency colour', 'size' => 6, 'name' => 'architect_footerimage_transparency_colour', 'value' => get_option('architect_footerimage_transparency_colour'), 'before' => '#', 'description' => 'What background colour do you want your footer image to have?'));

	// Show mobile footer image preview
	if(get_option('architect_footerimage') AND get_option('architect_use_footerimage'))
	{
		if(file_exists(WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'footer'.DIRECTORY_SEPARATOR.get_option('architect_footerimage')))
		{
			$src = '/wp-content/uploads/'.get_wapl_plugin_base().'/images/footer/'.get_option('architect_headerimage');
		} else if(file_exists(WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.'footer'.DIRECTORY_SEPARATOR.get_option('architect_footerimage')))
		{
			$src = '/wp-content/plugins/'.get_wapl_plugin_base().'/theme/images/footer/'.get_option('architect_footerimage');
		}
		echo architect_admin_option('image', array('label' => 'Mobile site footer image preview', 'alt' => 'Mobile Footer Image', 'src' => $src));
	}

	// Show footer text
	echo architect_admin_option('select', array('label' => 'Show footer text', 'name' => 'architect_showfootertext', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_showfootertext'), 'description' => 'Show footer text at the bottom of your site'));
	
	// Footer text
	echo architect_admin_option('input', array('label' => 'Footer Text', 'name' => 'architect_footertext', 'value' => get_option('architect_footertext'), 'description' => 'Define footer text to appear at the bottom of your site'));
	
	// Show menu at top
	echo architect_admin_option('select', array('label' => 'Show menu at top', 'name' => 'architect_showmenuattop', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_showmenuattop'), 'description' => 'Show your menu at the top'));
	
	// Show menu at bottom
	echo architect_admin_option('select', array('label' => 'Show menu at bottom', 'name' => 'architect_showmenuatbottom', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_showmenuatbottom'), 'description' => 'Show your menu at the bottom'));

	// Show switch to desktop option
	echo architect_admin_option('select', array('label' => 'Show switch to desktop', 'name' => 'architect_showswitchtodesktop', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_showswitchtodesktop'), 'description' => 'Show a \'switch to desktop\' link at the bottom'));

	// Show author on home page and posts page
	echo architect_admin_option('select', array('label' => 'Show post author name', 'name' => 'architect_showauthor', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_showauthor'), 'description' => 'Show author name on home page and post'));
	
	// Try and process forms
	echo architect_admin_option('select', array('label' => 'Process Forms', 'name' => 'architect_doform', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_doform'), 'description' => 'Process forms for mobile'));
	
	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Home Page Settings');
	
	// Show home page excerpt
	echo architect_admin_option('select', array('label' => 'Show excerpt on homepage', 'name' => 'architect_home_showexcerpt', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_home_showexcerpt'), 'description' => 'Show a bit of your post on the homepage'));
	
	// Show home page excerpt override
	echo architect_admin_option('input', array('size' => 5, 'label' => 'Home page excerpt chars limit', 'name' => 'architect_home_excerpt_override', 'value' => get_option('architect_home_excerpt_override'), 'description' => 'Restrict home page excerpt to this number of chars'));

	// Show categories at the bottom of the home page
	echo architect_admin_option('select', array('label' => 'Show categories on homepage', 'name' => 'architect_home_showcategories', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_home_showcategories'), 'description' => 'Show a list of categories at the bottom of the home page'));
	
	// Image scale on home page
	$homepagescale = ARCHITECT_HOME_IMAGESCALE;
	if(get_option('architect_home_imagescale'))
	{
		$homepagescale = get_option('architect_home_imagescale');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image scale on homepage', 'name' => 'architect_home_imagescale', 'value' => $homepagescale, 'after' => '% ', 'description' => 'Define how wide you want post images resized to with relation to screen width'));	

	// Image quality on home page
	$homepagequality = ARCHITECT_HOME_IMAGEQUALITY;
	if(get_option('architect_home_imagequality'))
	{
		$homepagequality = get_option('architect_home_imagequality');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image quality on homepage', 'name' => 'architect_home_imagequality', 'value' => $homepagequality, 'after' => '% ', 'description' => 'Define the quality of the image on the home page'));	
	
	// Show search on home page
	echo architect_admin_option('select', array('label' => 'Show search on home page', 'name' => 'architect_home_showsearch', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_home_showsearch'), 'description' => 'Show search box on the home page (appears at bottom)'));

	// Number of posts on home page
	$posts_per_page = get_option('posts_per_page');
	$option_posts_per_page = get_option('architect_home_posts_per_page');
	if($option_posts_per_page)
	{
		$posts_per_page = $option_posts_per_page;
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Posts on homepage', 'name' => 'architect_home_posts_per_page', 'value' => $posts_per_page, 'description' => 'Define the number of posts on the home page'));	

	// Show more link
	echo architect_admin_option('select', array('label' => 'Show read more link on home page', 'name' => 'architect_home_showmore', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_home_showmore'), 'description' => 'Show more link on home page'));
	
	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Posts / Archive Settings');
	
	// Allow comments on posts
	echo architect_admin_option('select', array('label' => 'Allow comments on posts', 'name' => 'architect_single_allowcomments', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_single_allowcomments'), 'description' => 'Allow commenting from mobile'));
	
	// Pagination on posts
	echo architect_admin_option('select', array('label' => 'Do pagination', 'name' => 'architect_single_dopaging', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_single_dopaging'), 'description' => 'Split up posts into smaller, easier to read pages'));
		
	// Pagination length
	$singlepagepaginglength = ARCHITECT_SINGLE_PAGINGLENGTH;
	if(get_option('architect_single_paginglength'))
	{
		$singlepagepaginglength = get_option('architect_single_paginglength');
	}
	echo architect_admin_option('input', array('size' => 4, 'label' => 'Post length', 'name' => 'architect_single_paginglength', 'value' => $singlepagepaginglength, 'after' => 'chars ', 'description' => 'Define length of post before splitting up into multiple pages'));

	// Read more / next page text
	echo architect_admin_option('input', array('size' => 10, 'label' => 'Read more on post', 'name' => 'architect_single_nextpage', 'value' => get_option('architect_single_nextpage'), 'description' => 'User defined read more link on post'));

	// Read less / prev page text
	echo architect_admin_option('input', array('size' => 10, 'label' => 'Go back on post', 'name' => 'architect_single_prevpage', 'value' => get_option('architect_single_prevpage'), 'description' => 'User defined go back link on post'));
	
	// Show home link on posts
	echo architect_admin_option('select', array('label' => 'Show home link', 'name' => 'architect_single_showhome', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_single_showhome'), 'description' => 'Show a link back to the home page'));
	
	// Show next/prev links on posts
	echo architect_admin_option('select', array('label' => 'Show next/previous links', 'name' => 'architect_single_shownext', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_single_shownext'), 'description' => 'Show next and previous posts'));
		
	// Image scale on posts
	$singlepagescale = ARCHITECT_SINGLE_IMAGESCALE;
	if(get_option('architect_single_imagescale'))
	{
		$singlepagescale = get_option('architect_single_imagescale');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image scale on post', 'name' => 'architect_single_imagescale', 'value' => $singlepagescale, 'after' => '% ', 'description' => 'Define how wide you want post images resized to with relation to screen width'));
	
	// Image quality on posts
	$singlepagequality = ARCHITECT_SINGLE_IMAGEQUALITY;
	if(get_option('architect_single_imagequality'))
	{
		$singlepagequality = get_option('architect_single_imagequality');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image quality on post', 'name' => 'architect_single_imagequality', 'value' => $singlepagequality, 'after' => '% ', 'description' => 'Define the quality of the image on the post'));
	
	// Responses text
	$options = array(
		'1' => '1 response',
		'2' => '1 response to [post title]',
		'3' => '1 comment',
		'4' => '1 comment to [post title]',
	);
	echo architect_admin_option('select', array('label' => '# responses text', 'name' => 'architect_single_responseformat', 'options' => $options, 'value' => get_option('architect_single_responseformat'), 'description' => 'Define the format of response text'));
	
	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Pages Settings');
	
	// Image scale on pages
	$pagescale = ARCHITECT_PAGE_IMAGESCALE;
	if(get_option('architect_page_imagescale'))
	{
		$pagescale = get_option('architect_page_imagescale');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image scale on page', 'name' => 'architect_page_imagescale', 'value' => $pagescale, 'after' => '% ', 'description' => 'Define how wide you want page images resized to with relation to screen width'));

	// Image quality on pages
	$pagequality = ARCHITECT_PAGE_IMAGEQUALITY;
	if(get_option('architect_page_imagequality'))
	{
		$pagequality = get_option('architect_page_imagequality');
	}
	echo architect_admin_option('input', array('size' => 2, 'label' => 'Image quality on page', 'name' => 'architect_page_imagequality', 'value' => $pagequality, 'after' => '% ', 'description' => 'Define the quality of the image on the page'));

	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Search Results Settings');
	
	// Show tags on search results
	echo architect_admin_option('select', array('label' => 'Show tags on search results', 'name' => 'architect_search_showtags', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_search_showtags'), 'description' => 'Show tags on search results'));
	
	// Show categories on search results
	echo architect_admin_option('select', array('label' => 'Show categories on search results', 'name' => 'architect_search_showcategories', 'options' => array('1' => 'Yes', '0' => 'No'), 'value' => get_option('architect_search_showcategories'), 'Show categories on search results'));
	
	echo '</table>';
	echo architect_table_start();
	echo architect_admin_header('3', 'Mobile Theme Settings');
	
	// Mobile stylesheet
	if(file_exists(WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'style.css'))
	{
		$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'style.css';
	} else
	{
		$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'style.css';
	}
	
	echo architect_admin_option('textarea', array('label' => 'Mobile Stylesheet', 'name' => 'architect_stylesheet', 'value' => file_get_contents($file)));

	// Custom stylesheet
	if(file_exists(WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'custom_style.css'))
	{
		$file = WP_UPLOAD_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'css'.DIRECTORY_SEPARATOR.'custom_style.css';
	} else
	{
		$file = WP_PLUGIN_DIR.DIRECTORY_SEPARATOR.get_wapl_plugin_base().DIRECTORY_SEPARATOR.'theme'.DIRECTORY_SEPARATOR.'custom_style.css';
	}
	echo architect_admin_option('textarea', array('label' => 'Custom Mobile Stylesheet', 'name' => 'architect_custom_stylesheet', 'value' => file_get_contents($file)));
	
	echo '</table>';
	echo '<table class="form-table" cellspacing="2" cellpadding="5" width="100%"><tr><td><p class="submit"><input class="button-primary" type="submit" name="info_update" value="Save Changes" /></p></td></tr></table></form></div>';
}

function architect_add_headerimage()
{
	echo '<input type="file" name="architect_add_headerimage" id="architect_add_headerimage" />';
}

if(!function_exists('get_wapl_plugin_base'))
{
	function get_wapl_plugin_base()
	{
		// Fix non conforming directory separators!
		$opposite = array('/' => '\\', '\\' => '/');
		$base = str_replace($opposite[DIRECTORY_SEPARATOR], DIRECTORY_SEPARATOR, plugin_basename(__FILE__));
		
		$baseExplode = explode(DIRECTORY_SEPARATOR, $base);
		return $baseExplode[0];
	}
}

function architect_check_path($path)
{
	$path = str_replace(WP_UPLOAD_DIR, '', $path);
	
	$dirExplode = explode(DIRECTORY_SEPARATOR, $path);
	$pathToCheck = WP_UPLOAD_DIR;
	foreach($dirExplode as $key => $val)
	{
		if(!file_exists($pathToCheck))
		{
			mkdir($pathToCheck, 0777);
		}
		$pathToCheck .= $val.DIRECTORY_SEPARATOR;
	}
}

if(!function_exists('architect_admin_header'))
{
	function architect_admin_header($h, $value)
	{
		return '<tr><td><h'.$h.' style="margin:0;font-size:1.3em;">'.$value.'</h'.$h.'></td></tr>';
	}
}
if(!function_exists('architect_table_start'))
{
	function architect_table_start()
	{
		return '<table class="form-table" cellspacing="2" cellpadding="5" width="100%" style="margin-top:5px;margin-bottom:0px;border:solid 1px #404040;">';
	}
}
if(!function_exists('architect_admin_option'))
{
	function architect_admin_option($type, $options = array())
	{
		$string  = '<tr>';
		$string .= '<th width="30%" valign="top" style="padding-top: 10px;">';
		
		if(isset($options['name']))
		{
			$string .= '<label for="'.$options['name'].'">'.$options['label'].': </label>';
		}
		$string .= '</th><td>';
		
		switch($type)
		{
			case 'input' : 
				if(!isset($options['size']))
				{
					$options['size'] = 40;
				}
				if(isset($options['before']) AND $options['before'] != '')
				{
					$string .= $options['before'];
				}
				$string .= '<input';
				
				if($options['size'] == 40)
				{
					$string .= ' class="regular-text"';
				}
				$string .= ' style="margin-right:10px;" size="'.$options['size'].'" type="text" name="'.$options['name'].'" id="'.$options['name'].'" value="'.$options['value'].'" />';
				
				if(isset($options['after']) AND $options['after'] != '')
				{
					$string .= $options['after'];
				}
				break;
			case 'select' :
				$string .= '<select name="'.$options['name'].'" style="margin-right:10px;">';
				foreach($options['options'] as $key => $val)
				{
					$string .= '<option value="'.$key.'"';
				
					if($key == $options['value'])
					{
						$string .= ' selected="selected"';
					}
					
					$string .= '>'.$val.'</option>';
				}
				$string .= '</select>';
				break;
			case 'file' :
				$string .= '<input type="file" name="'.$options['name'].'" id="'.$options['name'].'" style="margin-right:10px;" />';
				break;
			case 'image' :
				$string .= '<img src="'.$options['src'].'" alt="'.$options['alt'].'" style="margin-right:10px;" />';
				break;
			case 'textarea' :
				if(!isset($options['rows']))
				{
					$options['rows'] = 25;
				}
				if(!isset($options['cols']))
				{
					$options['cols'] = 70;
				}
				$string .= '<textarea style="margin-right:10px;" id="'.$options['name'].'" name="'.$options['name'].'" rows="'.$options['rows'].'" cols="'.$options['cols'].'">'.$options['value'].'</textarea>';
				break;
		}
		
		if(isset($options['description']))
		{
			$string .= '<span class="description">'.$options['description'].'</span>';
		}
		
		$string .= '</td></tr>';
		return $string;
	}
}

register_activation_hook(__FILE__, 'architect_install');

function architect_install()
{
	if(!$blog_id = get_option('blog_id'))
	{
		$blog_id = 0;
	}
	
	global $wpdb;
	
	$sql = '
	INSERT INTO `'.$wpdb->prefix.'options` 
	(`blog_id`, `option_name`, `option_value`, `autoload`) 
	VALUES
	('.$blog_id.', \'architect_headerimagelinktohome\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_home_imagescale\', \'50\', \'yes\'),
	('.$blog_id.', \'architect_home_imagequality\', \'95\', \'yes\'),
	('.$blog_id.', \'architect_single_imagescale\', \'50\', \'yes\'),
	('.$blog_id.', \'architect_single_imagequality\', \'95\', \'yes\'),
	('.$blog_id.', \'architect_page_imagescale\', \'50\', \'yes\'),
	('.$blog_id.', \'architect_page_imagequality\', \'95\', \'yes\'),
	('.$blog_id.', \'architect_single_paginglength\', \'2000\', \'yes\'),
	('.$blog_id.', \'architect_single_allowcomments\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_single_dopaging\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_showfootertext\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_single_showhome\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_single_nextpage\', \'more\', \'yes\'),
	('.$blog_id.', \'architect_single_prevpage\', \'back\', \'yes\'),
	('.$blog_id.', \'architect_single_shownext\', \'1\', \'yes\'),
	('.$blog_id.', \'architect_home_posts_per_page\', \''.get_option('posts_per_page').'\', \'yes\'),
	('.$blog_id.', \'architect_home_excerpt_override\', \'300\', \'yes\'),
	('.$blog_id.', \'architect_showfootertext\', \'Powered by Wapple Architect\', \'yes\')';
	$result = $wpdb->query($sql);
}

add_filter('plugin_row_meta', 'architect_filter_plugin_links', 10, 2);

// 
function architect_filter_plugin_links($links, $file)
{
	if ( $file == plugin_basename(__FILE__) )
	{
		$links[] = '<a href="options-general.php?page=architect.php">' . __('Settings') . '</a>';
	}
	
	return $links;
}
?>
