<?php
/**
 * @package Wapple_Architect
 * @subpackage WAPL Theme
 */
include_once('functions.php');
$waplString = get_wapl_header();
$wapl = new WordPressWapl;

// Posts per page
$posts_per_page = get_option('posts_per_page');
$option_posts_per_page = get_option('architect_home_posts_per_page');
if($option_posts_per_page)
{
	$posts_per_page = $option_posts_per_page;
}

// Offset paging
$offset = 0;
global $paged;
if($paged > 1)
{
	$offset = $posts_per_page * ($paged - 1);  
}

query_posts('showposts='.$posts_per_page.'&offset='.$offset);

if(have_posts())
{
	while(have_posts())
	{
		the_post();
		
		$waplString .= $wapl->link(array('rowClass' => 'entry_row h2', 'display_as' => 'h2', 'label' => get_the_title(), 'url' => apply_filters('the_permalink', get_permalink())));
		
		// Show the author
		if(get_option('architect_showauthor'))
		{
			$authorUrl = get_author_posts_url(get_the_author_ID());
			$waplString .= $wapl->link(array('cellClass' => 'author', 'prefix' => 'Written by: ', 'label' => get_the_author(), 'url' => $authorUrl));
		}
		$waplString .= $wapl->chunk('words', array('class' => 'post-date', 'quick_text' => apply_filters('the_time', get_the_time('F jS, Y'), 'F jS, Y')));
		
		if(get_option('architect_home_showexcerpt'))
		{
			$homepagescale = ARCHITECT_HOME_IMAGESCALE;
			$getVal = get_option('architect_home_imagescale');
			if(get_option('architect_home_imagescale'))
			{
				$homepagescale = get_option('architect_home_imagescale');
			}
			$homepagequality = ARCHITECT_HOME_IMAGEQUALITY;
			$getVal = get_option('architect_home_imagequality');
			if($getVal)
			{
				$homepagequality = $getVal;
			}

			$excerpt = get_the_content();
			
			if(!$excerptLength = get_option('architect_home_excerpt_override'))
			{
				$excerptLength = 300;
			}

			if(strlen($excerpt) > $excerptLength)
			{
				$excerpt = strip_tags(substr($excerpt, 0, $excerptLength)).'...';
			} 
			$content = $wapl->format_text($excerpt, $homepagescale, $homepagequality, 'entry_row');
			$waplString .= $wapl->chunk('words', array('class' => 'entry_row', 'quick_text' => $content));
		}
	}
	
	// Get next posts page
	global $paged, $wp_query;
	$max_page = 0;

	if ( !$max_page ) 
	{
		$max_page = $wp_query->max_num_pages;
	}

	if ( !$paged )
	{
		$paged = 1;
	}
	$nextpage = intval($paged) + 1;

	if ( !is_single() && ( empty($paged) || $nextpage <= $max_page) ) {
		$nextUrl = next_posts( $max_page, false );
	}
	
	$navString = '<row class="navigation">';
	$prevlink = '';
	$nextlink = '';
	$doEmpty = true;
	
	if(isset($nextUrl))
	{
		$navString .= $wapl->link(array('row' => false, 'cellClass' => 'older', 'url' => $nextUrl, 'label' => 'Older Posts'));
		$doEmpty = false;
	}
	
	if ( !is_single() && $paged > 1 ) 
	{
		$prevUrl = previous_posts( false );
	}
	
	if(isset($prevUrl))
	{
		$navString .= $wapl->link(array('row' => false, 'cellClass' => 'newer', 'url' => $prevUrl, 'label' => 'Newer Posts'));
		$doEmpty = false;
	}
	
	if($doEmpty == true)
	{
		$navString .= '<cell></cell>';
	}
	
	$navString .= '</row>';
	
	$waplString .= $navString;
} else
{
	$waplString .= $wapl->chunk('words', array('display_as' => 'h2', 'quick_text' => 'Not Found'));
	$waplString .= $wapl->chunk('words', array('quick_text' => 'Sorry, but you are looking for something that isn\'t here.'));
}

if(get_option('architect_home_showsearch'))
{
	$waplString .= get_wapl_element('search_box');
}

if(get_option('architect_home_showcategories'))
{
	$cats = get_categories(array('echo' => 0));
	if(!empty($cats))
	{
		$waplString .= $wapl->chunk('words', array('class' => 'homeCategoryHeader', 'display_as' => 'h3', 'quick_text' => 'Categories'));
		
		$waplString .= '<row><cell class="homeCategories">';
		foreach($cats as $cat)
		{
			$waplString .= $wapl->link(array('row' => false, 'cell' => false, 'prefix' => ' ', 'label' => $cat->name, 'url' => get_category_link( $cat->term_id )));
		}
		$waplString .= '</cell></row>';
	}
}

$waplString .= get_wapl_footer();
process_wapl($waplString);
?>